@@ -37,7 +37,7 @@ plot.perf_mddsPLS <- function(x,plot_mean=FALSE,legend_names=NULL,
 
   X_all <- scale(do.call(cbind,res_perf_mdd$Xs))
   if(res_perf_mdd$mode=="reg"){
-    cc <- matrix(NA,nrow = ncol(Y),ncol = ncol(X_all))
+    cc <- matrix(NA,nrow = ncol(res_perf_mdd$Y),ncol = ncol(X_all))
     for(j in 1:ncol(X_all)){
       cc[,j] <- abs(stats::cor(res_perf_mdd$Y,X_all[,j],use = "pairwise.complete.obs"))
     }
